@@ -50,8 +50,8 @@ downloads, installation and source code.
 
 __Conventions__  = 'CF-1.5'
 __author__       = 'David Hassell'
-__date__         = '05 November 2015'
-__version__      = '1.1.1'
+__date__         = '01 December 2015'
+__version__      = '1.1.2'
 
 from distutils.version import StrictVersion
 import imp
