@@ -44,7 +44,7 @@ True
         return True
     #--- End: def
 
-    def dump(self, display=True, domain=None, key=None, level=0):
+    def dump(self, display=True, domain=None, key=None, _level=0):
         '''
 
 Return a string containing a full description of the cell measure.
@@ -56,8 +56,6 @@ Return a string containing a full description of the cell measure.
         the description is printed, i.e. ``c.dump()`` is equivalent to
         ``print c.dump(display=False)``.
 
-    level : int, optional
-
 :Returns:
 
     out : None or str
@@ -66,8 +64,8 @@ Return a string containing a full description of the cell measure.
 :Examples:
 
 '''
-        indent1 = '    ' * level
-        indent2 = '    ' * (level+1)
+        indent1 = '    ' * _level
+        indent2 = '    ' * (_level+1)
 
         if hasattr(self, 'measure'):
             string = ['%sCell measure: %s' % (indent1, self.measure)]
@@ -87,7 +85,7 @@ Return a string containing a full description of the cell measure.
         #--- End: if
 
         if self._simple_properties():
-            string.append(self._dump_simple_properties(level=level+1))
+            string.append(self._dump_simple_properties(_level=_level+1))
           
         string = '\n'.join(string)
        
