@@ -361,9 +361,9 @@ AttributeError: Can't get cell sizes when coordinates have no bounds
                 "Can't get cell sizes when coordinates have no bounds")
 
         cells = self.bounds.data
-
+        print cell.array
         cells = (cells[:, 1] - cells[:, 0]).abs()
-
+        print cell.array
         cells.squeeze(1, i=True)
         
         return cells
@@ -1263,6 +1263,8 @@ Parameters :
 
     units : str or Units
 
+    {+i}
+
 :Returns: 
 
     None
@@ -1307,6 +1309,10 @@ are subsequently required.
         '''
 Join a sequence of coordinates together.
 
+:Returns:
+
+    out : cf.{+Variable}
+
 '''      
         coord0 = coordinates[0]
 
@@ -1317,11 +1323,7 @@ Join a sequence of coordinates together.
                                    _preserve=_preserve)
         
         if coord0._hasbounds:
-#            out.bounds = CoordinateBounds.concatenate(
-#                [c.bounds for c in coordinates],
-#                axis=axis, _preserve=_preserve)
-
-            bounds = CoordinateBounds.concatenate(
+            bounds = Variable.concatenate(
                 [c.bounds for c in coordinates],
                 axis=axis, _preserve=_preserve)
 
@@ -1411,7 +1413,7 @@ The Units are changed to '1' (nondimensionsal).
 
 :Parameters:
 
-    i : bool, optional
+    {+i}
 
 :Returns:
 
@@ -1478,6 +1480,7 @@ Set the cyclicity of axes of the data array and bounds.
         old = super(Coordinate, self).cyclic(axes, iscyclic)
 
         if axes is not None and self._hasbounds:
+            axes = _parse_axes(axes)
             self.bounds.cyclic(axes, iscyclic)
 
         return old
@@ -1497,7 +1500,7 @@ The Units are changed to '1' (nondimensionsal).
 
 :Parameters:
 
-    i : bool, optional
+    {+i}
 
 :Returns:
 
@@ -1623,7 +1626,7 @@ None
         return
     #--- End: def
 
-    def dump(self, display=True, omit=(), domain=None, key=None, level=0): 
+    def dump(self, display=True, omit=(), domain=None, key=None, _level=0): 
         '''
 
 Return a string containing a full description of the coordinate.
@@ -1646,8 +1649,8 @@ Return a string containing a full description of the coordinate.
 :Examples:
 
 '''
-        indent0 = '    ' * level
-        indent1 = '    ' * (level+1)
+        indent0 = '    ' * _level
+        indent1 = '    ' * (_level+1)
 
         string = []
 
@@ -1673,7 +1676,7 @@ Return a string containing a full description of the coordinate.
         #--- End: if
 
         if self._simple_properties():
-            string.append(self._dump_simple_properties(level=level))
+            string.append(self._dump_simple_properties(_level=_level))
 
         string = '\n'.join(string)
        
@@ -1697,7 +1700,7 @@ Insert a size 1 axis into the data array and bounds in place.
         axis is to be inserted. By default the new axis is inserted at
         position 0, the slowest varying position.
 
-    i : bool, optional
+    {+i}
 
 :Returns:
 
@@ -1718,7 +1721,8 @@ Insert a size 1 axis into the data array and bounds in place.
 
         if c._hasbounds and c.bounds._hasData:
             # Expand the coordinate's bounds
-            c.bounds.Data.expand_dims(position, i=True)
+            position = _parse_axes([position])[0]
+            c.bounds.expand_dims(position, i=True)
 
 #        if i:
 #            c = self
@@ -1752,6 +1756,8 @@ coordinate is 1 or 0 dimensional.
         Flip the dimensions whose positions are given. By default all
         dimensions are flipped.
 
+    {+i}
+
 :Returns:
 
     out : cf.Coordinate
@@ -1766,17 +1772,7 @@ coordinate is 1 or 0 dimensional.
 True
 
 '''
-#        if (not self._hasData and
-#            (not self._hasbounds or not self.bounds._hasData)):
-#            raise ValueError(
-#                "Can't transpose '%s'" % self.__class__.__name__)
-
-#        if self._hasData:
         c = super(Coordinate, self).flip(axes, i=i)
-#        elif i:
-#            c = self
-#        else:
-#            c = self.copy()
 
         # ------------------------------------------------------------
         # Flip the requested dimensions in the coordinate's bounds, if
@@ -1798,7 +1794,10 @@ True
                 if axes in (0, -1):
                     axes = (0, -1)
                 elif axes is not None:
-                    axes = list(axes) + [-1]
+                    axes = _parse_axes(axes) + [-1]
+            else:
+                # Do not flip the bounds of N-d coordinates (N >= 2)
+                axes = _parse_axes(axes)
 
             c.bounds.flip(axes, i=True)            
         #--- End if
@@ -1900,6 +1899,7 @@ with the `insert_bounds` method.
 
     def override_units(self, new_units, i=False):
         '''
+    {+i}
 
 '''
         if i:
@@ -1921,6 +1921,7 @@ with the `insert_bounds` method.
 
     def roll(self, axis, shift, i=False):
         '''
+    {+i}
 '''      
         if self.size <= 1:
             if i:
@@ -1994,7 +1995,7 @@ The Units are changed to '1' (nondimensionsal).
 
 :Parameters:
 
-    i : bool, optional
+    {+i}
 
 :Returns:
 
@@ -2045,7 +2046,7 @@ Take the logarithm the data array and bounds element-wise.
 
     base : number, optional
     
-    i : bool, optional
+    {+i}
 
 :Returns:
 
@@ -2079,6 +2080,8 @@ Remove size 1 dimensions from the data array and bounds in place.
         removed. Size 1 axes for removal may be identified by the
         integer positions of dimensions in the data array.
 
+    {+i}
+
 :Returns:
 
     out : cf.Coordinate
@@ -2090,20 +2093,11 @@ Remove size 1 dimensions from the data array and bounds in place.
 >>> c.squeeze([1, 2])
 
 '''
-#        if (not self._hasData and
-#            (not self._hasbounds or not self.bounds._hasData)):
-#            raise ValueError(
-#                "Can't squeeze '%s'" % self.__class__.__name__)
-
-#        if self._hasData:
         c = super(Coordinate, self).squeeze(axes, i=i)
-#        elif i:
-#            c = self
-#        else:
-#            c = self.copy()
 
         if c._hasbounds and c.bounds._hasData:
             # Squeeze the bounds
+            axes = _parse_axes(axes)
             c.bounds.squeeze(axes, i=True)
 
         return c
@@ -2125,9 +2119,11 @@ Permute the dimensions of the data array and bounds in place.
         integer positions of the dimensions in the data array in the
         desired order.
 
+    {+i}
+
 :Returns:
 
-    out cf.Coordinate
+    out : cf.Coordinate
 
 :Examples:
 
@@ -2137,26 +2133,29 @@ Permute the dimensions of the data array and bounds in place.
 >>> c.transpose([1, 2, 0])
 
 '''
-#        if (not self._hasData and
-#            (not self._hasbounds or not self.bounds._hasData)):
-#            raise ValueError(
-#                "Can't transpose '%s'" % self.__class__.__name__)
-
-#        if self._hasData:
         c = super(Coordinate, self).transpose(axes, i=i)
-#        elif i:
-#            c = self
-#        else:
-#            c = self.copy()
 
-        if c._hasbounds and c.ndim > 1 and c.bounds._hasData:
+        ndim = c.ndim
+        if c._hasbounds and ndim > 1 and c.bounds._hasData:
             # Transpose the bounds
             if axes is None:
-                axes = range(c.ndim-1, -1, -1) + [-1]
+                axes = range(ndim-1, -1, -1) + [-1]
             else:
-                axes = list(axes) + [-1]
+                axes = _parse_axes(axes) + [-1]
                 
-            c.bounds.transpose(axes, i=True)
+            bounds = c.bounds
+            bounds.transpose(axes, i=True)
+
+            if (ndim == 2 and
+                bounds.shape[-1] == 4 and 
+                axes[0] == 1 and 
+                (c.Units.islongitude or c.Units.islatitude or
+                 c.getprop('standard_name', None) in ('grid_longitude' or
+                                                      'grid_latitude'))):
+                # Swap columns 1 and 3 so that the coordinates are
+                # still contiguous (if they ever were). See section
+                # 7.1 of the CF conventions.
+                bounds.subspace[..., [1, 3]] = bounds.subspace[..., [3, 1]]
         #--- End: if
 
         return c
@@ -2399,7 +2398,6 @@ AttributeError: Can't get cell sizes when coordinates have no bounds
 #                bounds_range = bounds_range.override_units(self.Units)
 #            cells.clip(*bounds_range, units=bounds_range.Units, i=True)
 #        #--- End: if
-
         if self.direction():            
             cells = cells[:, 1] - cells[:, 0]
         else:
@@ -2829,6 +2827,8 @@ range, value)
 
     def roll(self, axis, shift, i=False):
         '''
+    {+i}
+
 '''
         if self.size <= 1:
             if i:
@@ -3037,3 +3037,8 @@ False
     #--- End: def
 
 #--- End: class
+
+def _parse_axes(axes):
+    if axes is None:
+        return axes
+    return [(i + ndim if i < 0 else i) for i in axes]
