@@ -416,8 +416,9 @@ follows:
 def REGRID_LOGGING(*arg):
     """
 
-Whether or not to enable ESMPy logging. If it is logging is performed after
-every call to ESMPy.
+Whether or not to enable ESMPy logging.
+
+If it is logging is performed after every call to ESMPy.
 
 :Parameters:
 
@@ -1102,7 +1103,6 @@ def set_subspace(array, indices, value):
         # normal numpy assignment
         # ------------------------------------------------------------
         array[tuple(indices)] = value
-        
     else:
         # ------------------------------------------------------------
         # At least two axes have list-of-integers indices so we can't
@@ -1309,11 +1309,6 @@ False
     eq = getattr(x, 'equals', None)
     if callable(eq):
         # x has a callable equals method
-        if rtol is None:
-            rtol = RTOL()
-        if atol is None:
-            atol = ATOL()
-
         return eq(y, rtol=rtol, atol=atol,
                   ignore_fill_value=ignore_fill_value,
                   traceback=traceback)
@@ -1322,11 +1317,6 @@ False
     eq = getattr(y, 'equals', None)
     if callable(eq):
         # y has a callable equals method
-        if rtol is None:
-            rtol = RTOL()
-        if atol is None:
-            atol = ATOL()
-
         return eq(x, rtol=rtol, atol=atol,
                   ignore_fill_value=ignore_fill_value,
                   traceback=traceback)
@@ -1352,6 +1342,31 @@ False
         return x == y
 #--- End: def
 
+def set_equals(x, y, rtol=None, atol=None, ignore_fill_value=False,
+               traceback=False):
+    '''
+'''    
+    eq = getattr(x, 'set_equals', None)
+    if callable(eq):
+        # x has a callable set_equals method
+        return eq(y, rtol=rtol, atol=atol,
+                  ignore_fill_value=ignore_fill_value,
+                  traceback=traceback)
+    #--- End: if
+
+    eq = getattr(y, 'set_equals', None)
+    if callable(eq):
+        # y has a callable set_equals method
+        return eq(x, rtol=rtol, atol=atol,
+                  ignore_fill_value=ignore_fill_value,
+                  traceback=traceback)
+    #--- End: if
+
+    return equals(x, y, rtol=rtol, atol=atol,
+                  ignore_fill_value=ignore_fill_value,
+                  traceback=traceback)
+#--- End: def
+
 def equivalent(x, y, rtol=None, atol=None, traceback=False):
     '''
 
@@ -2075,27 +2090,30 @@ cf.Data.
         object. If axes is None (the default) all axes are selected.
     
     data : bool, optional
-        If True this indicates that a data object has been passed, if false it
-        indicates that a field object has been passed. By default it is false.
+        If True this indicates that a data object has been passed, if
+        false it indicates that a field object has been passed. By
+        default it is false.
 
     stop : int, optional
-        Stop after taking this number of sections and return. If stop is None
-        all sections are taken.
+        Stop after taking this number of sections and return. If stop
+        is None all sections are taken.
 
 :Returns:
 
     out : list or dict
-        The list of m dimensional sections of the Field with the or the
+        The list of m dimensional sections of the Field or the
         dictionary of m dimensional sections of the Data object.
 
 :Examples:
 
 Section a field into 2D longitude/time slices, checking the units:
 
->>> _section(f, {None: 'longitude', units: 'radians'},\
-...             {None: 'time', 'units': 'days since 2006-01-01 00:00:00'})
+>>> _section(f, {None: 'longitude', units: 'radians'},
+...             {None: 'time',
+...              'units': 'days since 2006-01-01 00:00:00'})
 
-Section a field into 2D longitude/latitude slices, requiring exact names:
+Section a field into 2D longitude/latitude slices, requiring exact
+names:
 
 >>> _section(f, ['latitude', 'longitude'], exact=True)
 
