@@ -181,17 +181,17 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
 >>> cf.read('file*.nc')[-1]
 <CF Field: temperature_wind(17, 29, 24)>
 
->>> cf.read('file*.nc', prop={'units': 'K'})
+>>> cf.read('file*.nc', select='units:K)
 [<CF Field: temperature(17, 30, 24)>,
  <CF Field: temperature_wind(17, 29, 24)>]
 
->>> cf.read('file*.nc', attr={'ncvar': 'ta'})
-[<CF Field: temperature(17, 30, 24)>]
+>>> cf.read('file*.nc', select='ncvar%ta')
+<CF Field: temperature(17, 30, 24)>
 
->>> cf.read('file*.nc', prop={'standard_name': '.*pmsl*', 'units':'K|Pa'})[0]
+>>> cf.read('file*.nc', select={'standard_name': '.*pmsl*', 'units':['K', 'Pa']})
 <CF Field: pmsl(30, 24)>
 
->>> cf.read('file*.nc', prop={'units':['K', 'Pa']})
+>>> cf.read('file*.nc', select={'units':['K', 'Pa']})
 [<CF Field: pmsl(30, 24)>,
  <CF Field: temperature(17, 30, 24)>,
  <CF Field: temperature_wind(17, 29, 24)>]
