@@ -40,6 +40,7 @@ class DataTest(unittest.TestCase):
 #    test_only = ('test_Data_array', 'test_Data_varray', 'test_Data_dtarray',)
 #    test_only = ('test_dumpd_loadd',)
 #    test_only = ('test_Data_year_month_day_hour_minute_second',)
+#    test_only =  ('test_Data_BINARY_AND_UNARY_OPERATORS',)
 
     # Variables for _collapse
     a = numpy.arange(-100, 200., dtype=float).reshape(3, 4, 5, 5) 
@@ -551,9 +552,9 @@ class DataTest(unittest.TestCase):
         for chunksize in self.chunk_sizes:   
             cf.CHUNKSIZE(chunksize)          
             d = cf.Data([[4, 2, 1], [1, 2, 3]], 'metre')
-            self.assertTrue((d.unique == cf.Data([1, 2, 3, 4], 'metre')).all())
+            self.assertTrue((d.unique() == cf.Data([1, 2, 3, 4], 'metre')).all())
             d[1, -1] = cf.masked
-            self.assertTrue((d.unique == cf.Data([1, 2, 4], 'metre')).all())
+            self.assertTrue((d.unique() == cf.Data([1, 2, 4], 'metre')).all())
 
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
@@ -663,8 +664,9 @@ class DataTest(unittest.TestCase):
                     self.assertTrue((d -  x).equals(cf.Data(a0 -  x, 'm' ), traceback=1)), '%s-%s'  % (repr(d), x)
                     self.assertTrue((d // x).equals(cf.Data(a0 // x, 'm' ), traceback=1)), '%s//%s' % (repr(d), x)
                     self.assertTrue((d ** x).equals(cf.Data(a0 ** x, 'm2'), traceback=1)), '%s**%s' % (repr(d), x)
-
+                    
                     self.assertTrue(d.__truediv__(x).equals(cf.Data(a0.__truediv__(x), 'm'), traceback=1)), '%s.__truediv__(%s)' % (d, x)
+
                     self.assertTrue(d.__rtruediv__(x).equals(cf.Data(a0.__rtruediv__(x), 'm-1'), traceback=1)) , '%s.__rtruediv__(%s)' % (d, x)
           
 #                    print '%s {+, -, *, /, //, **, __truediv__, __rtruediv__} %s passed' % (d, x),                         "pmshape =", d._pmshape
@@ -684,41 +686,76 @@ class DataTest(unittest.TestCase):
     
 #                    print '%s {+, -, *, /, //, **} %s passed' % (x, repr(d)), "pmshape =", d._pmshape
                 
-                    e = d.copy()
-                    a = a0.copy()
-                    e += x
-                    a += x
-                    self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s+=%s' % (repr(d), x)
-                    e = d.copy()
-                    a = a0.copy()
-                    e *= x
-                    a *= x
-                    self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s*=%s' % (repr(d), x)
-                    e = d.copy()
-                    a = a0.copy()
-                    e /= x
-                    a /= x
-                    self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s/=%s' % (repr(d), x)
-                    e = d.copy()
-                    a = a0.copy()
-                    e -= x
-                    a -= x
-                    self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s-=%s' % (repr(d), x)
-                    e = d.copy()
-                    a = a0.copy()
-                    e //= x
-                    a //= x
-                    self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s//=%s' % (repr(d), x)
-                    e = d.copy()
-                    a = a0.copy()
-                    e **= x
-                    a **= x
-                    self.assertTrue(e.equals(cf.Data(a, 'm2'), traceback=1)), '%s**=%s' % (repr(d), x)
-                    e = d.copy()
-                    a = a0.copy()
-                    e.__itruediv__(x)
-                    a.__itruediv__(x)
-                    self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s.__itruediv__(%s)' % (d, x)
+                    a = a0.copy()                        
+                    try:
+                        a += x
+                    except TypeError:
+                        pass
+                    else:
+                        e = d.copy()
+                        e += x
+                        self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s+=%s' % (repr(d), x)
+
+                    a = a0.copy()                        
+                    try:
+                        a *= x
+                    except TypeError:
+                        pass
+                    else:
+                        e = d.copy()
+                        e *= x
+                        self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s*=%s' % (repr(d), x)
+
+                    a = a0.copy()                        
+                    try:
+                        a /= x
+                    except TypeError:
+                        pass
+                    else:
+                        e = d.copy()
+                        e /= x
+                        self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s/=%s' % (repr(d), x)
+
+                    a = a0.copy()                        
+                    try:
+                        a -= x
+                    except TypeError:
+                        pass
+                    else:
+                        e = d.copy()
+                        e -= x
+                        self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s-=%s' % (repr(d), x)
+
+                    a = a0.copy()                        
+                    try:
+                        a //= x
+                    except TypeError:
+                        pass
+                    else:
+                        e = d.copy()
+                        e //= x
+                        self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s//=%s' % (repr(d), x)
+
+
+                    a = a0.copy()                        
+                    try:
+                        a **= x
+                    except TypeError:
+                        pass
+                    else:
+                        e = d.copy()
+                        e **= x
+                        self.assertTrue(e.equals(cf.Data(a, 'm2'), traceback=1)), '%s**=%s' % (repr(d), x)
+
+                    a = a0.copy()                        
+                    try:
+                        a.__itruediv__(x)
+                    except TypeError:
+                        pass
+                    else:
+                        e = d.copy()
+                        e.__itruediv__(x)
+                        self.assertTrue(e.equals(cf.Data(a, 'm'), traceback=1)), '%s.__itruediv__(%s)' % (d, x)
                 
 #                    print '%s {+=, -=, *=, /=, //=, **=, __itruediv__} %s passed' % (repr(d), x),                         "pmshape =", d._pmshape
                 #--- End: for
