@@ -1,3 +1,4 @@
+
 import os
 import numpy
 import cf
@@ -20,10 +21,14 @@ class FieldTest(unittest.TestCase):
 #    test_only = ('test_Field_transpose','test_Field_squeeze',)
 #    test_only = ('test_Field_collapse',)
 #    test_only = ('test_Field_match','test_Field_items',)
+#    test_only = ('test_Field_items',)
 #    test_only = ('test_Field_axes','test_Field_data_axes',)
 #    test_only = ('test_Field_where',)
+#    test_only = ('test_Field_anchor',)
+#    test_only = ('test_Field_period',)
+#    test_only = ('test_FieldList_argless_methods',)
 
-    def test_Field_anchor(self):    
+    def test_Field_anchor(self):  
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -156,6 +161,33 @@ class FieldTest(unittest.TestCase):
 
         self.assertTrue(set(f.items('atmosphere_hybrid_height_coordinate')) == set(['dim0','ref0']))
 
+        self.assertTrue(set(f.items(axes='X'))       == set(['dim2','aux2','aux3','msr0']))
+        self.assertTrue(set(f.items(axes='Y'))       == set(['dim1','aux2','aux3','aux4','msr0']))
+        self.assertTrue(set(f.items(axes='Z'))       == set(['dim0','aux0','aux1']))
+        self.assertTrue(set(f.items(axes=['X','Y'])) == set(['dim1','dim2','aux2','aux3','aux4','msr0']))
+        self.assertTrue(set(f.items(axes=['X','Z'])) == set(['dim0','dim2','aux0','aux1','aux2','aux3','msr0']))
+        self.assertTrue(set(f.items(axes=['Z','Y'])) == set(['dim0','dim1','aux0','aux1','aux2','aux3','aux4','msr0']))
+
+        self.assertTrue(set(f.items(axes_all='X'))       == set(['dim2']))
+        self.assertTrue(set(f.items(axes_all='Y'))       == set(['dim1','aux4']))
+        self.assertTrue(set(f.items(axes_all='Z'))       == set(['dim0','aux0','aux1']))
+        self.assertTrue(set(f.items(axes_all=['X','Y'])) == set(['aux2','aux3','msr0']))
+        self.assertTrue(set(f.items(axes_all=['X','Z'])) == set([]))
+        self.assertTrue(set(f.items(axes_all=['Z','Y'])) == set([]))
+
+        self.assertTrue(set(f.items(axes_subset='X'))       == set(['dim2','aux2','aux3','msr0']))
+        self.assertTrue(set(f.items(axes_subset='Y'))       == set(['dim1','aux2','aux3','aux4','msr0']))
+        self.assertTrue(set(f.items(axes_subset='Z'))       == set(['dim0','aux0','aux1']))
+        self.assertTrue(set(f.items(axes_subset=['X','Y'])) == set(['aux2','aux3','msr0']))
+        self.assertTrue(set(f.items(axes_subset=['X','Z'])) == set([]))
+        self.assertTrue(set(f.items(axes_subset=['Z','Y'])) == set([]))
+
+        self.assertTrue(set(f.items(axes_superset='X'))       == set(['dim2']))
+        self.assertTrue(set(f.items(axes_superset='Y'))       == set(['dim1','aux4']))
+        self.assertTrue(set(f.items(axes_superset='Z'))       == set(['dim0','aux0','aux1']))
+        self.assertTrue(set(f.items(axes_superset=['X','Y'])) == set(['dim1','dim2','aux2','aux3','aux4','msr0']))
+        self.assertTrue(set(f.items(axes_superset=['X','Z'])) == set(['dim0','dim2','aux0','aux1']))
+        self.assertTrue(set(f.items(axes_superset=['Z','Y'])) == set(['dim0','dim1','aux0','aux1','aux4']))
     #--- End: def
 
     def test_Field_match(self):
@@ -231,7 +263,7 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        f = self.f.copy()
+        f = cf.read(self.filename)
         f.dim('X').period(None)
         f.cyclic('X', False)
         self.assertTrue(f.period('X') is None)
@@ -239,7 +271,7 @@ class FieldTest(unittest.TestCase):
         self.assertTrue(f.period('X') == cf.Data(360, 'degrees'))
         f.cyclic('X', False)
         self.assertTrue(f.period('X') == cf.Data(360, 'degrees'))
-        f.dim('X').period(None)
+        f[0].dim('X').period(None)
         self.assertTrue(f.period('X') is None)
     #--- End: def
 
@@ -247,18 +279,16 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        f = cf.read(self.filename)[0]
-        f = f.squeeze()
-        self.assertTrue(f is f.squeeze(i=True))
-        self.assertTrue(f.equals(f.squeeze()))
+        f0 = cf.read(self.filename)
 
-        for chunksize in self.chunk_sizes:            
-            cf.CHUNKSIZE(chunksize)            
-            f = cf.read(self.filename)[0]
-             
-            pass # for now!
+        for f in (f0, cf.FieldList(f0)):       
+            f.squeeze(i=True)
+            g = f.copy()
+            h = f.copy()
+            i = h.squeeze(i=True)
+            self.assertTrue(f.equals(g))
+            self.assertTrue(h is i)
         #--- End: for    
-        cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
 
     def test_Field_transpose(self):
@@ -305,7 +335,7 @@ class FieldTest(unittest.TestCase):
 
             for m in range(1, 13):
                 a = numpy.empty((5, 4, 5))
-                for i, year in enumerate(f.subspace(T=cf.month(m)).coord('T').year.unique):
+                for i, year in enumerate(f.subspace(T=cf.month(m)).coord('T').year.unique()):
                     q = cf.month(m) & cf.year(year)
                     x = f.subspace(T=q)
                     x.data.mean(axes=0, i=True)
@@ -331,25 +361,37 @@ class FieldTest(unittest.TestCase):
 
             for condition in (True, 1, [[[True]]], [[[[[456]]]]]):
                 g = f.where(condition, -9)
-                self.assertTrue(g.min() == -9)
-                self.assertTrue(g.max() == -9)                
+                self.assertTrue(g[0].min() == -9)
+                self.assertTrue(g[0].max() == -9)                
 
             g = f.where(cf.le(34), 34)
-            self.assertTrue(g.min() == 34)
-            self.assertTrue(g.max() == 89)   
+            self.assertTrue(g[0].min() == 34)
+            self.assertTrue(g[0].max() == 89)   
 
             g = f.where(cf.le(34), cf.masked)
-            self.assertTrue(g.min() == 35)
-            self.assertTrue(g.max() == 89) 
+            self.assertTrue(g[0].min() == 35)
+            self.assertTrue(g[0].max() == 89) 
 
             g = f.where(cf.le(34), cf.masked, 45)
-            self.assertTrue(g.min() == 45)
-            self.assertTrue(g.max() == 45)               
+            self.assertTrue(g[0].min() == 45)
+            self.assertTrue(g[0].max() == 45)               
         #--- End: for
 
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def   
 
+    def test_Field_mask_invalid(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        f = cf.read(self.filename)[0]
+
+        g = f.mask_invalid()
+        g = cf.FieldList(f).mask_invalid()
+        g = f.mask_invalid(i=True)
+        g = cf.FieldList(f).mask_invalid(i=True)
+    #--- End: def
+    
 #--- End: class
 
 if __name__ == '__main__':
